pub type Result<T> = Result<T, ProblemResponse>;Expand description
Response result alias for handlers that emit structured problem details.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(ProblemResponse),
}pub type Result<T> = Result<T, ProblemResponse>;Response result alias for handlers that emit structured problem details.
pub enum Result<T> {
Ok(T),
Err(ProblemResponse),
}