pub fn wrap_read(messages: &[Bytes]) -> Result<Bytes>Expand description
Wrap messages in JSON array for read.
Takes a collection of JSON message bytes and wraps them in a JSON array.
If the input is empty, returns an empty array [].
Errors
This function currently does not return errors and always returns Ok.