pub fn deserialize_offset<'de, D: Deserializer<'de>>(
d: D,
) -> Result<Offset, D::Error>Expand description
Deserialize an Offset from its canonical string representation.
Errors
Returns an error if the underlying deserializer fails to produce a
string, or if the string cannot be parsed as a valid Offset.